function [bd_parts, macro_mesh] = domain_bfs()
% backward facing step problem
% \bar{Omega} = [-2,0] x [0,1] \cup [0,4] x [-1,1] 
% 
% Input: empty
%
% Output:
% bd_parts     =  cell with informations about boundary conditions
% macro_mesh   =  structure with information about macro mesh topology
% structure of a grid (the case of one mesh-element)
%
%  grid_obj = struct('NVT',4, ...
%                    'NEDG', 4, ...
%                    'NEL',  1, ...
%                    'KCOORD',  zeros(4,2), ...
%                    'KVERT',  zeros(1,4), ...
%                    'KEDGE',  zeros(1,4), ...
%                    'KADJ', zeros(1,4) ...
%                   )		 
%
%
% NVT     = number of vertices
% NEDG    = number of edges
% NEL     = number of elements
% KCOORD  = matrix of vertex coordinates
% KVERT   = matrix of vertex numbers
% KEDGE   = matrix of edge numbers  
% KADJ    = matrix of adjacent elements
%
% call:
% [bd_parts, macro_mesh] = domain_bfs()


global NMVT NMEDG NMEL MCOORD MVERT MEDGE MADJ

NMEL=5;
NMVT=11;
NMEDG=15;

% pre-allocation

% coordinates of vertices
MCOORD = zeros(NMVT,2);

% vertex numbers
MVERT = zeros(NMEL,4);

% edge numbers
MEDGE = zeros(NMEL,4);

% adjacent matrix
MADJ = zeros(NMEL,4);


% setting

MCOORD = [  0  -1;   % Ecke 1
	    2  -1;   % Ecke 2
            4  -1;   % Ecke 3 
	    4   0;   % Ecke 4
	    2   0;   % Ecke 5
            0   0;   % Ecke 6 
           -2   0;   % Ecke 7
           -2   1;   % Ecke 8
            0   1;   % Ecke 9
            2   1;   % Ecke 10
            4   1;   % Ecke 11
         ];


MVERT = [   1   2   5   6;   % Element 1
	    2   3   4   5;   % Element 2
            7   6   9   8;   % Element 3 
	    6   5  10   9;   % Element 4
	    5   4  11  10;   % Element 5
	];


MEDGE = [ 1   4   7   5;   % Element 1 
	  2   3   8   4;   % Element 2 
	  6  11  13  12;   % Element 3
	  7  10  14  11;   % Element 4
	  8   9  15  10;   % Element 5
        ];


MADJ = [ -3   2   4  -3;   % Element 1
	   -2  -3   5   1;   % Element 2    Diri-case, part 2 (zero)
         -3   4  -3  -1;   % Element 3    Diri-case, part 1
	    1   5  -3   3;   % Element 4    Neumann-case, part 3
	    2  -3  -3   4;   % Element 5
       ];

% storing into structure

macro_mesh = struct('NVT',NMVT, ...
                    'NEDG', NMEDG , ...
                    'NEL', NMEL , ...
                    'KCOORD', MCOORD , ...
                    'KVERT',  MVERT, ...
                    'KEDGE', MEDGE , ...
                    'KADJ', MADJ ...
                   );

% boundary setting

N_bd_parts=3;

bd_parts = cell(N_bd_parts,1);

% ... as 'global' stored function handles (from 'examples_heat.m')
global  bc_fct_1  bc_fct_2  bc_fct_3 

% Dirichlet part
bd_parts{1} = struct('bc_type', 'D', 'bc_fct', bc_fct_1); % line x = -2
% Dirichlet part
bd_parts{2} = struct('bc_type', 'D', 'bc_fct', bc_fct_2);
% Neumann part
bd_parts{3} = struct('bc_type', 'D', 'bc_fct', bc_fct_3);

end

