function p1 = plotgrid(NEL, NEDG, NVT, KCOORD, KVERT, KEDGE, KADJ, fig_nr)
% Input:
% NEL     = Anzahl der Elemente  
% NEDG    = Anzahl der Element-Kanten
% NVT     = Anzahl der Element-Ecken
% KCOORD  = Matrix mit Koordinaten der Element-Ecken
% KVERT   = Matrix mit Element-Eck-Nummern
% KEDGE   = Matrix mit Element-Kanten-Nummern  
% KADJ    = Matrix mit Element-Kantennachbarschaften
% fig_nr  = Nr. des erzeugtes Bildes
%
% Output:
% 
% call:
% [] = plotgrid((NEL, NEDG, NVT, KCOORD, KVERT, KEDGE, KADJ)

xmin = min(KCOORD(:,1));
ymin = min(KCOORD(:,2));
xmax = max(KCOORD(:,1));
ymax = max(KCOORD(:,2));

figure(fig_nr);
clf;

% Hilfsvektor fuer Element-Ecken-Nummer
v  = zeros(4,1);

% Hilfsvektor fuer Koordinaten der Element-Ecken
XY = zeros(4,2);

% Hilfsvektor fuer Element-Kanten-Nummer
k = zeros(4,1);

% Schleife ueber Elemente
for m=1:NEL

 % Schleife ueber Element-Ecken
 for i=1:4   
   % Nummer der Element-Ecke 
   v(i) = KVERT(m,i);
   
   % Nummer der Element-Kante
   k(i) = KEDGE(m,i);
   
   % Koordinaten der Element-Ecke
   XY(i,:) = KCOORD(v(i),:);
 end;

 XC=0.25*sum(XY(:,1));
 YC=0.25*sum(XY(:,2));
 %text(XC,YC,num2str(m),'BackgroundColor',[0 0 0], 'Color', [1 1 1], 'LineWidth',0.5);
 text(XC,YC,num2str(m),'BackgroundColor',[1 1 1], 'EdgeColor',[0 0 1],'Color', [0 0 1], 'LineWidth',0.5);
 

 hold on;

 axis([xmin-1 xmax+1 ymin-1 ymax+1]);

 for i= 1:4

  % Nummer des Nachfolgers  
  ip = i+1;
  % Nummer des Vorgaengers
  im = i-1;
  % Vorgaenger der Ecke 1 ist die Ecke 4
  if(i==1)
   im = 4;
  end;
  % Nachfolger der Ecke 4 ist die Ecke 1
  if(i==4)
   ip = 1;
  end;

  k=KEDGE(m,i);
  a=KADJ(m,i);
  if(a<0)
   plot([XY(i,1), XY(ip,1)], [XY(i,2), XY(ip,2)], '-r','LineWidth',2);
   plot([XY(i,1), XY(ip,1)], [XY(i,2), XY(ip,2)], 'ok','MarkerFaceColor','k','MarkerSize',6);
  else
    plot([XY(i,1),XY(ip,1)],[XY(i,2), XY(ip,2)],'-ok','MarkerFaceColor','k','MarkerSize',6);
  end;

 
 end;

 FSe = 10;  % FontSize for edges
 % Kante 1
 d=0;
 xk=(XY(1,1)+XY(2,1))/2;
 yk=(XY(1,2)+XY(2,2))/2;
 k=KEDGE(m,1);
 text(xk,yk,num2str(k),'BackgroundColor',[1 1 1],'EdgeColor',[0 0 0], 'LineWidth',0.2,'FontSize',FSe,'Margin',1,'VerticalAlignment','middle');

 % Kante 2
 d=0;
 xk=(XY(2,1)+XY(3,1))/2;
 yk=(XY(2,2)+XY(3,2))/2;
 k=KEDGE(m,2);
 text(xk,yk,num2str(k),'BackgroundColor',[1 1 1], 'EdgeColor',[0 0 0], 'LineWidth',0.2,'FontSize',FSe,'Margin',1,'VerticalAlignment','middle');

 % Kante 3
 d=0;
 xk=(XY(3,1)+XY(4,1))/2;
 yk=(XY(3,2)+XY(4,2))/2;
 k=KEDGE(m,3);
 text(xk,yk,num2str(k),'BackgroundColor',[1 1 1], 'EdgeColor',[0 0 0], 'LineWidth',0.2,'FontSize',FSe,'Margin',1,'VerticalAlignment','middle');

 % Kante 4
 d=0;
 xk=(XY(4,1)+XY(1,1))/2;
 yk=(XY(4,2)+XY(1,2))/2;
 k=KEDGE(m,4);
 text(xk,yk,num2str(k),'BackgroundColor',[1 1 1], 'EdgeColor',[0 0 0],'LineWidth',0.2,'FontSize',FSe,'Margin',1,'VerticalAlignment','middle');


 FSv = 10;  % FontSize for edges
% Ecke 1
 d=0.06;
 xk=XY(1,1)+d;
 yk=XY(1,2)-d;
 v=KVERT(m,1);
 text(xk,yk,num2str(v),'FontSize',FSv);

 % Ecke 2
 xk=XY(2,1)+d; 
 yk=XY(2,2)-d;
 v=KVERT(m,2);
 text(xk,yk,num2str(v),'FontSize',FSv);
 

 % Ecke 3
 xk=XY(3,1)+d;
 yk=XY(3,2)-d;
 v=KVERT(m,3);
 text(xk,yk,num2str(v),'FontSize',FSv);

 
 % Ecke 4
 xk=XY(4,1)+d;
 yk=XY(4,2)-d;
 v=KVERT(m,4);
 text(xk,yk,num2str(v),'FontSize',FSv);



end;

title('data of the grid');
xlabel('x','FontSize',16);
ylabel('y','FontSize',16);
p1=0;

% ... save figure as png-file
%fig_file =  sprintf( 'mesh_NEL_%03i.png',NEL); % file-name of figure-file
%print( '-dpng',  fig_file);

fig_file =  sprintf( 'mesh_NEL_%03i.eps',NEL); % file-name of figure-file
print( '-depsc',  fig_file);

